@@ -346,7 +346,7 @@ class License(DataClassJSONMixin):
     id: str
     dependencies: List[LicenseDependency]
     projects: List[LicenseProject]
-    severity: str
+    severity: Optional[str] = None
 
 
 @dataclass
@@ -376,7 +376,7 @@ class IssueCounts(DataClassJSONMixin):
 @dataclass
 class DependencyGraphPackageInfo(DataClassJSONMixin):
     name: str
-    version: str
+    version: Optional[str] = None
 
 
 @dataclass
@@ -430,7 +430,7 @@ class Dependency(DataClassJSONMixin):
     latestVersionPublishedDate: Optional[str] = None
     firstPublishedDate: Optional[str] = None
     isDeprecated: Optional[bool] = None
-    packageManager: Optional[str] = None
+    type: Optional[str] = None
     deprecatedVersions: Optional[List[Any]] = field(default_factory=list)
     dependenciesWithIssues: Optional[List[Any]] = field(default_factory=list)
 
@@ -448,9 +448,13 @@ class Project(DataClassJSONMixin):
     totalDependencies: int
     lastTestedDate: str
     browseUrl: str
+    isMonitored: bool
     issueCountsBySeverity: IssueCounts
     imageTag: Optional[str] = None
     imageId: Optional[str] = None
+    imageBaseImage: Optional[str] = None
+    imagePlatform: Optional[str] = None
+    imageCluster: Optional[str] = None
     hostname: Optional[str] = None
     remoteRepoUrl: Optional[str] = None
     branch: Optional[str] = None
